@@ -49,9 +49,6 @@ class EAT():
 
         input_series = df.drop(columns=['date']).values
         y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))
-        print("y")
-        print(y)
-        print("\n")
         self.fcast = ahead.eatf(y=y, h=self.h, level=self.level, type_pi=self.type_pi,
                                 weights=FloatVector(self.weights))        
 
